@@ -6,10 +6,10 @@ describe 'keystone server running with Apache/WSGI with resources' do
 
     it 'should work with no errors' do
       pp= <<-EOS
-      include ::openstack_integration
-      include ::openstack_integration::repos
-      include ::openstack_integration::mysql
-      include ::openstack_integration::keystone
+      include openstack_integration
+      include openstack_integration::repos
+      include openstack_integration::mysql
+      include openstack_integration::keystone
 
       ::keystone::resource::service_identity { 'beaker-ci':
         service_type        => 'beaker',
@@ -318,7 +318,7 @@ EOC
       context 'manifest' do
         let(:pp) do
       <<-EOM
-      class { '::openstack_integration::keystone':
+      class { 'openstack_integration::keystone':
         default_domain      => 'default_domain',
         using_domain_config => true,
       }
@@ -349,8 +349,17 @@ EOC
           it_behaves_like 'a_valid_configuration', <<-EOC
 
 [ldap]
+use_pool=False
+pool_retry_delay=0.1
 url=ldap://foo
+auth_pool_size=100
+auth_pool_connection_lifetime=60
 user=cn=foo,dc=example,dc=com
+pool_connection_timeout=-1
+use_auth_pool=False
+pool_connection_lifetime=600
+pool_size=10
+pool_retry_max=3
 EOC
         end
 
@@ -358,8 +367,17 @@ EOC
           it_behaves_like 'a_valid_configuration', <<-EOC
 
 [ldap]
+pool_retry_delay=0.1
 url=ldap://bar
 user=cn=bar,dc=test,dc=com
+use_pool=False
+pool_retry_max=3
+pool_size=10
+auth_pool_size=100
+auth_pool_connection_lifetime=60
+use_auth_pool=False
+pool_connection_lifetime=600
+pool_connection_timeout=-1
 EOC
         end
       end
