@@ -23,6 +23,8 @@ describe 'keystone' do
       'admin_password'                     => 'special_password',
       'package_ensure'                     => 'present',
       'client_package_ensure'              => 'present',
+      'public_bind_host'                   => '0.0.0.0',
+      'public_port'                        => '5000',
       'catalog_type'                       => 'sql',
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
@@ -69,7 +71,7 @@ describe 'keystone' do
       'password_hash_rounds'               => '29000',
       'revoke_driver'                      => 'kvs',
       'revoke_by_id'                       => false,
-      'public_endpoint'                    => 'https://localhost:5000/v2.0/',
+      'public_endpoint'                    => 'https://localhost:5000',
       'enable_ssl'                         => true,
       'ssl_certfile'                       => '/etc/keystone/ssl/certs/keystone.pem',
       'ssl_keyfile'                        => '/etc/keystone/ssl/private/keystonekey.pem',
@@ -181,7 +183,7 @@ describe 'keystone' do
       if param_hash['public_endpoint']
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value(param_hash['public_endpoint'])
       else
-        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')
       end
     end
 
@@ -200,19 +202,6 @@ describe 'keystone' do
       is_expected.to contain_keystone_config('DEFAULT/max_token_size').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'should contain correct eventlet server config' do
-      [
-       'public_bind_host',
-       'public_port',
-      ].each do |config|
-        if param_hash[config]
-          is_expected.to contain_keystone_config("eventlet_server/#{config}").with_value(param_hash[config])
-        else
-          is_expected.to_not contain_keystone_config("eventlet_server/#{config}")
-        end
-      end
-    end
-
     it 'should ensure rabbit_ha_queues' do
       if param_hash['rabbit_ha_queues']
         is_expected.to contain_keystone_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(param_hash['rabbit_ha_queues'])
@@ -256,7 +245,7 @@ describe 'keystone' do
     end
 
     let :pre_condition do
-      'include ::keystone::wsgi::apache'
+      'include keystone::wsgi::apache'
     end
 
     it_configures 'core keystone examples', httpd_params
@@ -278,7 +267,7 @@ describe 'keystone' do
     end
 
     let :pre_condition do
-      'include ::keystone::wsgi::apache'
+      'include keystone::wsgi::apache'
     end
 
     it_configures 'core keystone examples', httpd_params
@@ -295,6 +284,49 @@ describe 'keystone' do
     ) }
   end
 
+  describe 'when public_bind_host or public_bind_port are set' do
+    describe 'when ipv6 loopback is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '::0'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[::1]:5000') }
+    end
+
+    describe 'when ipv4 address is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '192.168.0.1',
+          :public_port      => '15000'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://192.168.0.1:15000') }
+    end
+
+    describe 'when unenclosed ipv6 address is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '2001:db8::1'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
+    end
+
+    describe 'when enclosed ipv6 address is set' do
+      let :params do
+        {
+          :admin_token      => 'service_token',
+          :public_bind_host => '[2001:db8::1]'
+        }
+      end
+      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
+    end
+  end
+
   describe 'when using invalid service name for keystone' do
     let (:params) { {'service_name' => 'foo'}.merge(default_params) }
 
@@ -520,7 +552,7 @@ describe 'keystone' do
       {
         'admin_token'     => 'service_token',
         'enable_ssl'      => true,
-        'public_endpoint' => 'https://localhost:5000/v2.0/',
+        'public_endpoint' => 'https://localhost:5000',
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(true)}
@@ -529,8 +561,9 @@ describe 'keystone' do
     it {is_expected.to contain_keystone_config('ssl/ca_certs').with_value('/etc/keystone/ssl/certs/ca.pem')}
     it {is_expected.to contain_keystone_config('ssl/ca_key').with_value('/etc/keystone/ssl/private/cakey.pem')}
     it {is_expected.to contain_keystone_config('ssl/cert_subject').with_value('/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost')}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000/v2.0/')}
+    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000')}
   end
+
   describe 'when disabling SSL' do
     let :params do
       {
@@ -539,8 +572,9 @@ describe 'keystone' do
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(false)}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')}
+    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')}
   end
+
   describe 'not setting notification settings by default' do
     let :params do
       default_params
@@ -681,37 +715,6 @@ describe 'keystone' do
     it { is_expected.to contain_keystone_config('catalog/template_file').with_value('/etc/keystone/default_catalog.templates') }
   end
 
-  describe 'with overridden validation_auth_url' do
-    let :params do
-      {
-        :admin_token       => 'service_token',
-        :validate_service  => true,
-        :validate_auth_url => 'http://some.host:5000/v2.0',
-        :admin_endpoint    => 'http://some.host:5000'
-      }
-    end
-
-    it { is_expected.to contain_class('keystone::service').with(
-      'validate'       => true,
-      'admin_endpoint' => 'http://some.host:5000/v2.0'
-    )}
-  end
-
-  describe 'with service validation' do
-    let :params do
-      {
-        :admin_token      => 'service_token',
-        :validate_service => true,
-        :admin_endpoint   => 'http://some.host:5000'
-      }
-    end
-
-    it { is_expected.to contain_class('keystone::service').with(
-      'validate'       => true,
-      'admin_endpoint' => 'http://some.host:5000'
-    )}
-  end
-
   describe 'setting another template catalog' do
     let :params do
       {
@@ -958,7 +961,7 @@ describe 'keystone' do
     end
     describe 'with default domain and wsgi service is managed and enabled' do
       let :pre_condition do
-        'include ::apache'
+        'include apache'
       end
       let :params do
         default_params.merge({
