@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'keystone::wsgi::apache' do
 
   let :pre_condition do
-    "class { '::keystone':
+    "class { 'keystone':
        admin_token  => 'dummy',
        service_name => 'httpd',
        enable_ssl   => true,
@@ -184,9 +184,6 @@ describe 'keystone::wsgi::apache' do
         is_expected.to contain_file('/etc/apache2/sites-available/keystone.conf').with(
           :ensure  => 'file',
           :content => '')
-        is_expected.to contain_file('/etc/apache2/sites-enabled/keystone.conf').with(
-          :ensure  => 'file',
-          :content => '')
       }
     end
   end
